This package implements TcGSA, an algorithm to analyze longitudinal gene-expression data at the gene set level.
| Package: | TcGSA |
| Type: | Package |
| Version: | 0.10.5 |
| Date: | 2017-05-03 |
| License: | LGPL-3 |
The main function in this package is TcGSA.LR which performs Time-course Gene Set Analysis, and provide nice representations of its results (see plot.TcGSA and plot1GS).
Hejblum BP, Skinner J, Thiebaut R, (2015) Time-Course Gene Set Analysis for Longitudinal Gene Expression Data. PLoS Computat Biol 11(6): e1004310. doi: 10.1371/journal.pcbi.1004310