Learn R Programming

TcGSA (version 0.10.1)

summary.TcGSA: Summarizing TcGSA

Description

summary method for class 'TcGSA'

Usage

"summary"(object, ...)
"print"(x, ...)

Arguments

object
an object of class 'TcGSA'.
x
an object of class 'summary.TcGSA'.
...
further arguments passed to or from other methods.

Value

The function summary.TcGSA returns a list with the following components (list elements):
  • time_func the chosen form for the time trend.
  • separateSubjects a logical flag indicating wether gene sets tested for discriminating among patients, or for time trends over time.
  • ntg the number of treatment groups.
  • ngs the number of tested gene sets.
  • nsignif the number of significant gene sets at a 5% FDR (using the default Benjamini & Yekutieli step-up procedure).

See Also

TcGSA.LR

Examples

Run this code

data(data_simu_TcGSA)

tcgsa_sim_1grp <- TcGSA.LR(expr=expr_1grp, gmt=gmt_sim, design=design, 
                          subject_name="Patient_ID", time_name="TimePoint",
                          time_func="linear", crossedRandom=FALSE)
summary(tcgsa_sim_1grp)

## Not run: 
# tcgsa_sim_2grp <- TcGSA.LR(expr=expr_2grp, gmt=gmt_sim, design=design, 
#                           subject_name="Patient_ID", time_name="TimePoint",
#                           time_func="linear", crossedRandom=FALSE, 
#                           group_name="group.var")
# summary(tcgsa_sim_2grp)
# ## End(Not run)

Run the code above in your browser using DataLab